@@ -57,7 +57,10 @@ dzl_shortcut_closure_chain_append (DzlShortcutClosureChain *chain,
   if (chain == NULL)
     return element;
 
-  ret = g_slist_append (&chain->node, &element->node)->data;
+  if (element == NULL)
+    return chain;
+
+  ret = g_slist_concat (&chain->node, &element->node)->data;
 
   g_return_val_if_fail (ret != NULL, NULL);
 
